@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.iap_v1.types import service
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
@@ -172,9 +174,9 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def set_iam_policy(
         self,
-        request: iam_policy_pb2.SetIamPolicyRequest = None,
+        request: Union[iam_policy_pb2.SetIamPolicyRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
@@ -184,7 +186,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
         https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
 
         Args:
-            request (:class:`google.iam.v1.iam_policy_pb2.SetIamPolicyRequest`):
+            request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
                 The request object. Request message for `SetIamPolicy`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -280,9 +282,9 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def get_iam_policy(
         self,
-        request: iam_policy_pb2.GetIamPolicyRequest = None,
+        request: Union[iam_policy_pb2.GetIamPolicyRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
@@ -292,7 +294,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
         https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
 
         Args:
-            request (:class:`google.iam.v1.iam_policy_pb2.GetIamPolicyRequest`):
+            request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
                 The request object. Request message for `GetIamPolicy`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -388,9 +390,9 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def test_iam_permissions(
         self,
-        request: iam_policy_pb2.TestIamPermissionsRequest = None,
+        request: Union[iam_policy_pb2.TestIamPermissionsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
@@ -400,7 +402,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
         https://cloud.google.com/iap/docs/managing-access#managing_access_via_the_api
 
         Args:
-            request (:class:`google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest`):
+            request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
                 The request object. Request message for
                 `TestIamPermissions` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -441,9 +443,9 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def get_iap_settings(
         self,
-        request: service.GetIapSettingsRequest = None,
+        request: Union[service.GetIapSettingsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IapSettings:
@@ -451,7 +453,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
         resource.
 
         Args:
-            request (:class:`google.cloud.iap_v1.types.GetIapSettingsRequest`):
+            request (Union[google.cloud.iap_v1.types.GetIapSettingsRequest, dict]):
                 The request object. The request sent to GetIapSettings.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -488,9 +490,9 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def update_iap_settings(
         self,
-        request: service.UpdateIapSettingsRequest = None,
+        request: Union[service.UpdateIapSettingsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IapSettings:
@@ -498,7 +500,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
         It replaces all fields unless the ``update_mask`` is set.
 
         Args:
-            request (:class:`google.cloud.iap_v1.types.UpdateIapSettingsRequest`):
+            request (Union[google.cloud.iap_v1.types.UpdateIapSettingsRequest, dict]):
                 The request object. The request sent to
                 UpdateIapSettings.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
